# pktt

pktt is a Python library for showing mean, standard deviation of Gaussian distributions or probability & trial for binomial distributions.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install pktt.

```bash
pip install pktt
```

## Usage

```python
from pktt import Gaussian, Binomial 

Gaussian(10,7)
Binomial(.4,25)
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)